"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var moment = require("moment");
var _ = require("lodash");
var Helpers;
(function (Helpers) {
    function getLongestStreak(completions) {
        if (_.isEmpty(completions)) {
            return 0;
        }
        var longestStreak = 1;
        var orderedCompletions = _.orderBy(completions, 'endTime', 'asc');
        var currentStreak = 1;
        for (var i = 0; i < orderedCompletions.length - 1; i++) {
            var current = moment(orderedCompletions[i].endTime).startOf('d');
            var next = moment(orderedCompletions[i + 1].endTime).startOf('d');
            var diff = next.diff(current, 'd');
            // same day
            if (diff === 0) {
                continue;
            }
            else if (diff === 1) {
                currentStreak += 1;
            }
            else {
                currentStreak = 1;
            }
            if (currentStreak > longestStreak) {
                longestStreak = currentStreak;
            }
        }
        return longestStreak;
    }
    Helpers.getLongestStreak = getLongestStreak;
    function getFullName(activeUser) {
        return activeUser.firstName + " " + activeUser.lastName;
    }
    Helpers.getFullName = getFullName;
    function getWorkoutDurationMS(completion) {
        var endTimeMS = moment(completion.endTime).toDate().getTime();
        var startTimeMS = moment(completion.startTime).toDate().getTime();
        return endTimeMS - startTimeMS;
    }
    Helpers.getWorkoutDurationMS = getWorkoutDurationMS;
    var MSPerHr = 1000 * 60 * 60;
    var MSPerMin = 1000 * 60;
    function getFormattedWorkoutTime(totalMS) {
        var duration = moment.duration(totalMS, 'ms');
        var minutes = duration.minutes();
        var hours = duration.hours();
        if (hours === 0) {
            return minutes + "m";
        }
        return hours + " h " + minutes + " m";
    }
    Helpers.getFormattedWorkoutTime = getFormattedWorkoutTime;
    function getFormattedDuration(startISO, endISO) {
        var duration = moment.duration(moment(endISO).diff(startISO));
        var seconds = duration.seconds();
        var minutes = duration.minutes();
        var hours = duration.hours();
        var dateStr = (seconds > 9) ? "" + seconds : "0" + seconds;
        dateStr = ((minutes > 9) ? "" + minutes : "0" + minutes) + ":" + dateStr;
        if (hours > 0) {
            dateStr = hours + ":" + dateStr;
        }
        return dateStr;
    }
    Helpers.getFormattedDuration = getFormattedDuration;
    function getFormattedDurationTillNow(startISO) {
        var endISO = new Date().toISOString();
        return getFormattedDuration(startISO, endISO);
    }
    Helpers.getFormattedDurationTillNow = getFormattedDurationTillNow;
    function getEstimatedLengthOfWorkoutMin(drills) {
        return _.sumBy(drills, 'estimatedMin');
    }
    Helpers.getEstimatedLengthOfWorkoutMin = getEstimatedLengthOfWorkoutMin;
})(Helpers = exports.Helpers || (exports.Helpers = {}));
