"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var moment = require("moment");
var chai_1 = require("chai");
var _1 = require(".");
function mockCompletion(startMoment, endMoment) {
    return {
        _id: 'blah',
        workoutId: 'blah',
        userId: 'blah',
        startTime: startMoment.toISOString(),
        endTime: endMoment.toISOString(),
        userName: 'blah'
    };
}
describe('#getLongestStreak', function () {
    it('should return 0 when no completions', function () {
        chai_1.assert.equal(_1.Helpers.getLongestStreak([]), 0);
    });
    it('should return 1 with 1 completion', function () {
        chai_1.assert.equal(_1.Helpers.getLongestStreak([
            mockCompletion(moment().subtract(2, 'h'), moment().subtract(1, 'h'))
        ]), 1);
    });
    it('should return correct amount A', function () {
        chai_1.assert.equal(_1.Helpers.getLongestStreak([
            mockCompletion(moment().subtract(3, 'd').subtract(1, 'h'), moment().subtract(3, 'd')),
            mockCompletion(moment().subtract(2, 'd').subtract(1, 'h'), moment().subtract(2, 'd')),
            mockCompletion(moment().subtract(1, 'd').subtract(1, 'h'), moment().subtract(1, 'd'))
        ]), 3);
    });
    it('should return correct amount B', function () {
        chai_1.assert.equal(_1.Helpers.getLongestStreak([
            mockCompletion(moment().subtract(11, 'd').subtract(1, 'h'), moment().subtract(11, 'd')),
            mockCompletion(moment().subtract(10, 'd').subtract(1, 'h'), moment().subtract(10, 'd')),
            mockCompletion(moment().subtract(8, 'd').subtract(1, 'h'), moment().subtract(8, 'd')),
            mockCompletion(moment().subtract(7, 'd').subtract(1, 'h'), moment().subtract(7, 'd')),
            mockCompletion(moment().subtract(6, 'd').subtract(1, 'h'), moment().subtract(6, 'd')),
            mockCompletion(moment().subtract(3, 'd').subtract(1, 'h'), moment().subtract(3, 'd')),
            mockCompletion(moment().subtract(2, 'd').subtract(1, 'h'), moment().subtract(2, 'd'))
        ]), 3);
    });
    it('streak at end', function () {
        chai_1.assert.equal(_1.Helpers.getLongestStreak([
            mockCompletion(moment().subtract(11, 'd').subtract(1, 'h'), moment().subtract(11, 'd')),
            mockCompletion(moment().subtract(10, 'd').subtract(1, 'h'), moment().subtract(10, 'd')),
            mockCompletion(moment().subtract(8, 'd').subtract(1, 'h'), moment().subtract(8, 'd')),
            mockCompletion(moment().subtract(5, 'd').subtract(1, 'h'), moment().subtract(5, 'd')),
            mockCompletion(moment().subtract(4, 'd').subtract(1, 'h'), moment().subtract(4, 'd')),
            mockCompletion(moment().subtract(3, 'd').subtract(1, 'h'), moment().subtract(3, 'd')),
            mockCompletion(moment().subtract(2, 'd').subtract(1, 'h'), moment().subtract(2, 'd'))
        ]), 4);
    });
    it('ignore multiple workouts in one day', function () {
        chai_1.assert.equal(_1.Helpers.getLongestStreak([
            mockCompletion(moment().subtract(11, 'd').subtract(1, 'h'), moment().subtract(11, 'd')),
            mockCompletion(moment().subtract(10, 'd').subtract(1, 'h'), moment().subtract(10, 'd')),
            mockCompletion(moment().subtract(10, 'd').subtract(1, 'h'), moment().subtract(10, 'd')),
            mockCompletion(moment().subtract(9, 'd').subtract(1, 'h'), moment().subtract(9, 'd')),
            mockCompletion(moment().subtract(3, 'd').subtract(1, 'h'), moment().subtract(3, 'd')),
            mockCompletion(moment().subtract(2, 'd').subtract(1, 'h'), moment().subtract(2, 'd'))
        ]), 3);
    });
});
