import { Models as M } from './models';
import * as moment from 'moment';
import * as _ from 'lodash';

export namespace Helpers {

  export function getLongestStreak(completions: M.IWorkoutCompletion[]) {

    if (_.isEmpty(completions)) { return 0; }

    let longestStreak = 1;
    const orderedCompletions = _.orderBy(completions, 'endTime', 'asc');

    let currentStreak = 1;
    
    for (let i = 0; i < orderedCompletions.length - 1; i++) {

      const current = moment(orderedCompletions[i].endTime).startOf('d');
      const next = moment(orderedCompletions[i + 1].endTime).startOf('d');
      
      const diff = next.diff(current, 'd');

      // same day
      if (diff === 0) {
        continue;
      } else if (diff === 1) {
        currentStreak += 1;
      } else {
        currentStreak = 1;
      }

      if (currentStreak > longestStreak) {
        longestStreak = currentStreak;
      }

    }

    return longestStreak;
  }

  export function getFullName(activeUser: M.IActivatedUser) {
    return `${activeUser.firstName} ${activeUser.lastName}`;
  }

  export function getWorkoutDurationMS(completion: M.IWorkoutCompletion) {
    const endTimeMS = moment(completion.endTime).toDate().getTime();
    const startTimeMS = moment(completion.startTime).toDate().getTime();
    return endTimeMS - startTimeMS;
  }

  const MSPerHr = 1000 * 60 * 60;
  const MSPerMin = 1000 * 60;

  export function getFormattedWorkoutTime(totalMS: number): string {
    const duration = moment.duration(totalMS, 'ms');
    const minutes = duration.minutes();
    const hours = duration.hours();
    if (hours === 0) {
      return `${minutes}m`;
    }
    return `${hours} h ${minutes} m`;
  }

  export function getFormattedDuration(startISO: string, endISO: string): string {
    const duration = moment.duration(moment(endISO).diff(startISO));
    let seconds = duration.seconds();
    let minutes = duration.minutes();
    let hours = duration.hours();
    let dateStr = (seconds > 9) ? `${seconds}` : `0${seconds}`;
    dateStr = `${(minutes > 9) ? `${minutes}` : `0${minutes}`}:${dateStr}`;
    if (hours > 0) {
      dateStr = `${hours}:${dateStr}`;
    }
    return dateStr;
  }

  export function getFormattedDurationTillNow(startISO: string): string {
    const endISO = new Date().toISOString();
    return getFormattedDuration(startISO, endISO);
  }

  export function getEstimatedLengthOfWorkoutMin(drills: M.IDrill[]) {
    return _.sumBy(drills, 'estimatedMin');
  }

}