export namespace Models {

  export enum LeaderboardTimeFilter {
    AllTime = 'at',
    ThisMonth = 'month',
    ThisWeek = 'week'
  }

  export enum DeviceTypes {
    Ios = 'iPhone',
    Android = 'Android'
  }

  export interface ITestSignupBody {
    email: string;
    deviceType: DeviceTypes;
  }

  export interface ITestSignup extends ITestSignupBody {
    _id?: string;
    date: string;
  }

  /**
   * User related
   */

  export interface IUserCreds {
    phoneNumber: string;
    password: string;
  }

  export interface IUnactivatedUserBody {
    phoneNumber: string;
    hsGradYear: number;
    firstName: string;
    lastName: string;
  }

  export interface IUnactivatedUser extends IUnactivatedUserBody {
    _id?: string;
    dateCreated: string;
    confirmCode: string;
  }

  export interface IActivatedUser extends IUnactivatedUserBody {
    _id?: string;
    type: UserType;
    dateJoined: string;
    hashedPass: string;
  }

  export interface IPlayerDTO {
    player: IActivatedUser;
    workoutCompletions: IWorkoutCompletion[];
    workouts: IWorkout[];
    drills: IDrill[];
  }

  export interface IAuthPlayerDTO {
    authToken: string;
    playerDTO: IPlayerDTO;
  }

  export interface ICreateCustomWorkoutBody {
    userId: string;
    durationMin: number;
    minorSkills: string[];
  }

  export enum SkillType {
    Major = 'Major',
    Minor = 'Minor'
  }

  export interface ISkill {
    _id: string;
    name: string;
    type: SkillType;
    minorSkills?: string[];
  }

  /**
   * Workout related
   */

  export enum WorkoutUserType {
    Individual = 'Individual',
    Group = 'Group'
  }

  export enum DrillUserType {
    Individual = 'Individual',
    Group = 'Group'
  }

  export enum UserType {
    Admin = 'Admin',
    Player = 'Player'
  }

  export interface IWorkout {
    _id: string;
    date_created: string;
    title: string;
    isCustom: boolean;
    type: WorkoutUserType;
    drills: string[];
    estimatedMin: number;
  }

  export enum DrillType {
    Timed = 'Timed',
    Percentile = 'Percentile'
  }

  export interface IDrill {
    _id: string;
    title: string;
    instructions: string;
    videoFileId: number;
    estimatedMin: number;
    minorSkills: string[];
    measurementType: DrillType | null;
    userType: DrillUserType;
  }

  export interface ITimedDrill extends IDrill {
    type: DrillType.Timed;
  }

  export interface IPercentileDrill extends IDrill {
    type: DrillType.Percentile;
    numAttempts: number;
  }

  export interface IDrillPerformanceBody {
    userId: string;
    drillId: string;
    startDate: string;
    endDate: string;
  }

  export interface IPercentileDrillPerformanceBody extends IDrillPerformanceBody {
    numSuccesses: number;
  }

  export interface IDrillPerformance extends IDrillPerformanceBody {
    _id?: string;
    date: string;
  }

  export interface IPercentileDrillPerformance extends IDrillPerformance {
    numSuccesses: number;
  }

  export interface IWorkoutCompletionBody {
    startTime: string;
    endTime: string;
    workoutId: string;
    userId: string;
  }

  export interface ISetWorkoutDTO {
    workouts: IWorkout[];
    drills: IDrill[];
  }

  export interface IWorkoutCompletion extends IWorkoutCompletionBody {
    _id?: string;
    userName: string;
  }

  export interface ILeaderboardEntry {
    userId: string;
    name: string;
    num_completions: number;
    total_workout_time_ms: number;
  }

  /**
   * Feedback related
   */

  export interface IMCQuestion {
    prompt: string;
    options: string[];
  }

  export interface IOnboardingSurveyResBody {
    answers: number[];
    userId: string;
  }

  export interface IOnboardingSurveyRes extends IOnboardingSurveyResBody {
    _id?: string;
    dateCreated: string;
  }

  export interface IPostWorkoutSurveyResBody {
    feedback?: string;
    answers: number[];
    userId: string;
    workoutId: string;
  }

  export interface IPostWorkoutSurveyRes extends IPostWorkoutSurveyResBody {
    _id?: string;
    dateCreated: string;
  }

}