import * as moment from 'moment';
import { assert } from 'chai';
import { Helpers, Models } from '.';

function mockCompletion(startMoment: moment.Moment, endMoment: moment.Moment): Models.IWorkoutCompletion {
  return {
    _id: 'blah',
    workoutId: 'blah',
    userId: 'blah',
    startTime: startMoment.toISOString(),
    endTime: endMoment.toISOString(),
    userName: 'blah'
  };
}

describe('#getLongestStreak', function() {
  it ('should return 0 when no completions', function() {
    assert.equal(Helpers.getLongestStreak([]), 0);
  });

  it ('should return 1 with 1 completion', function() {
    assert.equal(Helpers.getLongestStreak([
      mockCompletion(moment().subtract(2, 'h'), moment().subtract(1, 'h'))
    ]), 1);
  });

  it ('should return correct amount A', function() {
    assert.equal(Helpers.getLongestStreak([
      mockCompletion(moment().subtract(3, 'd').subtract(1, 'h'), moment().subtract(3, 'd')),
      mockCompletion(moment().subtract(2, 'd').subtract(1, 'h'), moment().subtract(2, 'd')),
      mockCompletion(moment().subtract(1, 'd').subtract(1, 'h'), moment().subtract(1, 'd'))
    ]), 3);
  });

  it ('should return correct amount B', function() {
    assert.equal(Helpers.getLongestStreak([
      mockCompletion(moment().subtract(11, 'd').subtract(1, 'h'), moment().subtract(11, 'd')),
      mockCompletion(moment().subtract(10, 'd').subtract(1, 'h'), moment().subtract(10, 'd')),
      mockCompletion(moment().subtract(8, 'd').subtract(1, 'h'), moment().subtract(8, 'd')),
      mockCompletion(moment().subtract(7, 'd').subtract(1, 'h'), moment().subtract(7, 'd')),
      mockCompletion(moment().subtract(6, 'd').subtract(1, 'h'), moment().subtract(6, 'd')),
      mockCompletion(moment().subtract(3, 'd').subtract(1, 'h'), moment().subtract(3, 'd')),
      mockCompletion(moment().subtract(2, 'd').subtract(1, 'h'), moment().subtract(2, 'd'))
    ]), 3);
  });

  it ('streak at end', function() {
    assert.equal(Helpers.getLongestStreak([
      mockCompletion(moment().subtract(11, 'd').subtract(1, 'h'), moment().subtract(11, 'd')),
      mockCompletion(moment().subtract(10, 'd').subtract(1, 'h'), moment().subtract(10, 'd')),
      mockCompletion(moment().subtract(8, 'd').subtract(1, 'h'), moment().subtract(8, 'd')),
      mockCompletion(moment().subtract(5, 'd').subtract(1, 'h'), moment().subtract(5, 'd')),
      mockCompletion(moment().subtract(4, 'd').subtract(1, 'h'), moment().subtract(4, 'd')),
      mockCompletion(moment().subtract(3, 'd').subtract(1, 'h'), moment().subtract(3, 'd')),
      mockCompletion(moment().subtract(2, 'd').subtract(1, 'h'), moment().subtract(2, 'd'))
    ]), 4);
  });

  it ('ignore multiple workouts in one day', function() {
    assert.equal(Helpers.getLongestStreak([
      mockCompletion(moment().subtract(11, 'd').subtract(1, 'h'), moment().subtract(11, 'd')),
      mockCompletion(moment().subtract(10, 'd').subtract(1, 'h'), moment().subtract(10, 'd')),
      mockCompletion(moment().subtract(10, 'd').subtract(1, 'h'), moment().subtract(10, 'd')),
      mockCompletion(moment().subtract(9, 'd').subtract(1, 'h'), moment().subtract(9, 'd')),
      mockCompletion(moment().subtract(3, 'd').subtract(1, 'h'), moment().subtract(3, 'd')),
      mockCompletion(moment().subtract(2, 'd').subtract(1, 'h'), moment().subtract(2, 'd'))
    ]), 3);
  });

});