export declare namespace Models {
    enum LeaderboardTimeFilter {
        AllTime = "at",
        ThisMonth = "month",
        ThisWeek = "week"
    }
    enum DeviceTypes {
        Ios = "iPhone",
        Android = "Android"
    }
    interface ITestSignupBody {
        email: string;
        deviceType: DeviceTypes;
    }
    interface ITestSignup extends ITestSignupBody {
        _id?: string;
        date: string;
    }
    /**
     * User related
     */
    interface IUserCreds {
        phoneNumber: string;
        password: string;
    }
    interface IUnactivatedUserBody {
        phoneNumber: string;
        hsGradYear: number;
        firstName: string;
        lastName: string;
    }
    interface IUnactivatedUser extends IUnactivatedUserBody {
        _id?: string;
        dateCreated: string;
        confirmCode: string;
    }
    interface IActivatedUser extends IUnactivatedUserBody {
        _id?: string;
        type: UserType;
        dateJoined: string;
        hashedPass: string;
    }
    interface IPlayerDTO {
        player: IActivatedUser;
        workoutCompletions: IWorkoutCompletion[];
        workouts: IWorkout[];
        drills: IDrill[];
    }
    interface IAuthPlayerDTO {
        authToken: string;
        playerDTO: IPlayerDTO;
    }
    interface ICreateCustomWorkoutBody {
        userId: string;
        durationMin: number;
        minorSkills: string[];
    }
    enum SkillType {
        Major = "Major",
        Minor = "Minor"
    }
    interface ISkill {
        _id: string;
        name: string;
        type: SkillType;
        minorSkills?: string[];
    }
    /**
     * Workout related
     */
    enum WorkoutUserType {
        Individual = "Individual",
        Group = "Group"
    }
    enum DrillUserType {
        Individual = "Individual",
        Group = "Group"
    }
    enum UserType {
        Admin = "Admin",
        Player = "Player"
    }
    interface IWorkout {
        _id: string;
        date_created: string;
        title: string;
        isCustom: boolean;
        type: WorkoutUserType;
        drills: string[];
        estimatedMin: number;
    }
    enum DrillType {
        Timed = "Timed",
        Percentile = "Percentile"
    }
    interface IDrill {
        _id: string;
        title: string;
        instructions: string;
        videoFileId: number;
        estimatedMin: number;
        minorSkills: string[];
        measurementType: DrillType | null;
        userType: DrillUserType;
    }
    interface ITimedDrill extends IDrill {
        type: DrillType.Timed;
    }
    interface IPercentileDrill extends IDrill {
        type: DrillType.Percentile;
        numAttempts: number;
    }
    interface IDrillPerformanceBody {
        userId: string;
        drillId: string;
        startDate: string;
        endDate: string;
    }
    interface IPercentileDrillPerformanceBody extends IDrillPerformanceBody {
        numSuccesses: number;
    }
    interface IDrillPerformance extends IDrillPerformanceBody {
        _id?: string;
        date: string;
    }
    interface IPercentileDrillPerformance extends IDrillPerformance {
        numSuccesses: number;
    }
    interface IWorkoutCompletionBody {
        startTime: string;
        endTime: string;
        workoutId: string;
        userId: string;
    }
    interface ISetWorkoutDTO {
        workouts: IWorkout[];
        drills: IDrill[];
    }
    interface IWorkoutCompletion extends IWorkoutCompletionBody {
        _id?: string;
        userName: string;
    }
    interface ILeaderboardEntry {
        userId: string;
        name: string;
        num_completions: number;
        total_workout_time_ms: number;
    }
    /**
     * Feedback related
     */
    interface IMCQuestion {
        prompt: string;
        options: string[];
    }
    interface IOnboardingSurveyResBody {
        answers: number[];
        userId: string;
    }
    interface IOnboardingSurveyRes extends IOnboardingSurveyResBody {
        _id?: string;
        dateCreated: string;
    }
    interface IPostWorkoutSurveyResBody {
        feedback?: string;
        answers: number[];
        userId: string;
        workoutId: string;
    }
    interface IPostWorkoutSurveyRes extends IPostWorkoutSurveyResBody {
        _id?: string;
        dateCreated: string;
    }
}
